@@ -52,10 +52,10 @@ const Application = new Lang.Class({
     Extends: Gtk.Application,
 
     _init: function() {
-        this.parent({ application_id: pkg.name,
-                      flags: Gio.ApplicationFlags.IS_SERVICE,
-                      inactivity_timeout: 60000 });
+        this.parent({ application_id: pkg.name });
         GLib.set_application_name(_("Weather"));
+        if (pkg.moduledir.startsWith('resource:///'))
+            this.set_inactivity_timeout(60000);
 
         this._searchProvider = new SearchProvider.SearchProvider(this);
     },
@@ -117,9 +117,6 @@ const Application = new Lang.Class({
 
         this.add_accelerator("Escape", "win.selection-mode(false)", null);
         this.add_accelerator("<Primary>a", "win.select-all", null);
-
-        if (!pkg.moduledir.startsWith('resource://')) // running from source
-            this.activate();
     },
 
     vfunc_activate: function() {
